import { CalloutAnnotationCollection } from "./igr-callout-annotation-collection";
import { IgrSeries } from "./igr-series";
import { CalloutCollisionMode } from "./CalloutCollisionMode";
import { IgrAnnotationLayer, IIgrAnnotationLayerProps } from "./igr-annotation-layer";
import { CalloutLayer } from "./CalloutLayer";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
export declare class IgrCalloutLayer extends IgrAnnotationLayer<IIgrCalloutLayerProps> {
    protected createImplementation(): CalloutLayer;
    readonly i: CalloutLayer;
    constructor(props: IIgrCalloutLayerProps);
    private _callouts;
    /**
     * Gets the current SeriesViewer object's child Series.
    */
    callouts: CalloutAnnotationCollection;
    /**
     * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
    */
    targetSeries: IgrSeries;
    /**
     * Gets or sets how to select the final value to annotate.
    */
    isAutoCalloutBehaviorEnabled: boolean;
    /**
     * Gets or sets the color to use for the axis annotation text. Leave unset for an automatic value.
    */
    calloutTextColor: string;
    /**
     * Gets or sets the color to use for the axis annotation backing. Leave unset for an automatic value.
    */
    calloutBackground: string;
    /**
     * Gets or sets the precision to use displaying values for interpolated crosshair positions.
    */
    calloutInterpolatedValuePrecision: number;
    /**
     * Gets or sets the color to use for the axis annotation outline. Leave unset for an automatic value.
    */
    calloutOutline: string;
    /**
     * Gets or sets the padding for the axis annotation backing. Leave unset for an automatic value.
    */
    calloutPadding: number;
    /**
     * Gets or sets the padding for the axis annotation backing. Leave unset for an automatic value.
    */
    calloutCollisionMode: CalloutCollisionMode;
    /**
     * Gets or sets the padding to add to the callout positioning. Leave unset for an automatic value.
    */
    calloutPositionPadding: number;
    /**
     * Gets or sets the stroke thickness for the axis annotation backing. Leave unset for an automatic value.
    */
    calloutStrokeThickness: number;
}
export interface IIgrCalloutLayerProps extends IIgrAnnotationLayerProps {
    /**
     * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
    */
    targetSeries?: IgrSeries;
    /**
     * Gets or sets how to select the final value to annotate.
    */
    isAutoCalloutBehaviorEnabled?: boolean;
    /**
     * Gets or sets the color to use for the axis annotation text. Leave unset for an automatic value.
    */
    calloutTextColor?: string;
    /**
     * Gets or sets the color to use for the axis annotation backing. Leave unset for an automatic value.
    */
    calloutBackground?: string;
    /**
     * Gets or sets the precision to use displaying values for interpolated crosshair positions.
    */
    calloutInterpolatedValuePrecision?: number;
    /**
     * Gets or sets the color to use for the axis annotation outline. Leave unset for an automatic value.
    */
    calloutOutline?: string;
    /**
     * Gets or sets the padding for the axis annotation backing. Leave unset for an automatic value.
    */
    calloutPadding?: number;
    /**
     * Gets or sets the padding for the axis annotation backing. Leave unset for an automatic value.
    */
    calloutCollisionMode?: CalloutCollisionMode;
    /**
     * Gets or sets the padding to add to the callout positioning. Leave unset for an automatic value.
    */
    calloutPositionPadding?: number;
    /**
     * Gets or sets the stroke thickness for the axis annotation backing. Leave unset for an automatic value.
    */
    calloutStrokeThickness?: number;
}
