import { IgrCategoryAxisBase, IIgrCategoryAxisBaseProps } from "./igr-category-axis-base";
import { CategoryAngleAxis } from "./CategoryAngleAxis";
/**
 * Represents a IgxDataChartComponent category angle axis. Useful for displaying radial categories.
*/
export declare class IgrCategoryAngleAxis extends IgrCategoryAxisBase<IIgrCategoryAngleAxisProps> {
    protected createImplementation(): CategoryAngleAxis;
    readonly i: CategoryAngleAxis;
    constructor(props: IIgrCategoryAngleAxisProps);
    /**
     * Checks if the axis is of angular type
    */
    readonly isAngular: boolean;
    /**
     * Indicates the angle in degress that the chart's 0th angle should be offset.
    */
    startAngleOffset: number;
    /**
     * Gets or sets the frequency of displayed labels.
     * The set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
    */
    interval: number;
    /**
     * Gets the effective value for the current Interval.
    */
    actualInterval: number;
    /**
     * Gets or sets the frequency of displayed minor lines.
     * The set value is a factor that determines how the minor lines will be displayed.
    */
    minorInterval: number;
    /**
     * Gets the effective value for the current MinorInterval.
    */
    actualMinorInterval: number;
    /**
     * Gets the scaled angle in radians from the raw axis value.
    
    * @param unscaledAngle  * The raw axis value.
    */
    getScaledAngle(unscaledAngle: number): number;
    /**
     * Gets the raw axis value from the scaled angle in radians.
    
    */
    getUnscaledAngle(scaledAngle: number): number;
}
export interface IIgrCategoryAngleAxisProps extends IIgrCategoryAxisBaseProps {
    /**
     * Indicates the angle in degress that the chart's 0th angle should be offset.
    */
    startAngleOffset?: number;
    /**
     * Gets or sets the frequency of displayed labels.
     * The set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
    */
    interval?: number;
    /**
     * Gets the effective value for the current Interval.
    */
    actualInterval?: number;
    /**
     * Gets or sets the frequency of displayed minor lines.
     * The set value is a factor that determines how the minor lines will be displayed.
    */
    minorInterval?: number;
    /**
     * Gets the effective value for the current MinorInterval.
    */
    actualMinorInterval?: number;
}
