import { TimeAxisDisplayType_$type } from "./TimeAxisDisplayType";
import { IgrTimeAxisBase } from "./igr-time-axis-base";
import { CategoryDateTimeXAxis } from "./CategoryDateTimeXAxis";
import { ensureEnum } from "igniteui-react-core/ES2015/componentUtil";
/**
 * Represents a category-based horizontal X axis that uses a DateTime scale.
*/
export class IgrCategoryDateTimeXAxis extends IgrTimeAxisBase {
    createImplementation() {
        return new CategoryDateTimeXAxis();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets if the current axis is a continuous rather than a discrete scale
    */
    get isContinuous() {
        return this.i.b4;
    }
    /**
     * Gets or sets the axis display type.
     * Continuous display type divides the axis into even intervals, where labels will not necessarily be aligned with data points.
     * Discrete display type will not use a constant interval, but will align each label with its data point.
    */
    get displayType() {
        return this.i.lt;
    }
    set displayType(v) {
        this.i.lt = ensureEnum(TimeAxisDisplayType_$type, v);
    }
    /**
     * Gets or sets the X axis time interval.
    */
    get interval() {
        return this.i.l3;
    }
    set interval(v) {
        this.i.l3 = +v;
    }
    /**
     * Gets the effective value for the current Interval.
    */
    get actualInterval() {
        return this.i.l0;
    }
    set actualInterval(v) {
        this.i.l0 = +v;
    }
    /**
     * Gets or sets the frequency of displayed minor lines.
     * The set value is a factor that determines how the minor lines will be displayed.
    */
    get minorInterval() {
        return this.i.l4;
    }
    set minorInterval(v) {
        this.i.l4 = +v;
    }
    /**
     * Gets the effective value for the current MinorInterval.
    */
    get actualMinorInterval() {
        return this.i.l1;
    }
    set actualMinorInterval(v) {
        this.i.l1 = +v;
    }
    get isCategoryDateTime() {
        return this.i.b3;
    }
    scrollIntoView(minimum, maximum) {
        this.i.ma(minimum, maximum);
    }
}
