import { CategoryItemHighlightType_$type } from "./CategoryItemHighlightType";
import { IgrAnnotationLayer } from "./igr-annotation-layer";
import { CategoryItemHighlightLayer } from "./CategoryItemHighlightLayer";
import { ensureBool, ensureEnum } from "igniteui-react-core/ES2015/componentUtil";
/**
 * Represents an annotation layer that highlights items in a series that use a category axis
 * either by drawing a banded shape at their position, or by rendering a marker at their position.
 * Depending on the type of series, the default highlight will be affected. To override
 * the type of highlight used, you can set the HighlightType property.
*/
export class IgrCategoryItemHighlightLayer extends IgrAnnotationLayer {
    createImplementation() {
        return new CategoryItemHighlightLayer();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
    */
    get targetSeries() {
        if (this.i.mt == null) {
            return null;
        }
        return this.i.mt.externalObject;
    }
    set targetSeries(v) {
        v == null ? this.i.mt = null : this.i.mt = v.i;
    }
    /**
     * Gets or sets whether to use value interpolation when drawing a line through the best value for the pointer position.
    */
    get useInterpolation() {
        return this.i.mx;
    }
    set useInterpolation(v) {
        this.i.mx = ensureBool(v);
    }
    /**
     * Gets or sets which type of highlight shape to use when highlighting items.
    */
    get highlightType() {
        return this.i.mr;
    }
    set highlightType(v) {
        this.i.mr = ensureEnum(CategoryItemHighlightType_$type, v);
    }
    /**
     * Gets or sets the template to use for marker visuals for the current series object.
    */
    get markerTemplate() {
        return this.i.nb;
    }
    set markerTemplate(v) {
        this.i.nb = v;
    }
    /**
     * Gets or sets the width to use for the highlight region if highlighting items in a grid aligned series (line, spline, etc), with a banded shape.
    */
    get bandHighlightWidth() {
        return this.i.mz;
    }
    set bandHighlightWidth(v) {
        this.i.mz = +v;
    }
    /**
     * Gets or sets whether to skip unknown values when searching for series values.
    */
    get skipUnknownValues() {
        return this.i.mw;
    }
    set skipUnknownValues(v) {
        this.i.mw = ensureBool(v);
    }
}
