import { IgPoint } from "igniteui-react-core/ES2015/IgPoint";
import { CategoryTransitionInMode } from "./CategoryTransitionInMode";
import { AssigningCategoryStyleEventArgs } from "./igr-assigning-category-style-event-args";
import { AssigningCategoryMarkerStyleEventArgs } from "./igr-assigning-category-marker-style-event-args";
import { IgrMarkerSeries, IIgrMarkerSeriesProps } from "./igr-marker-series";
import { CategorySeries } from "./CategorySeries";
/**
 * Represents the base class for IgxDataChartComponent category series.
*/
export declare abstract class IgrCategorySeries<P extends IIgrCategorySeriesProps = IIgrCategorySeriesProps> extends IgrMarkerSeries<P> {
    readonly i: CategorySeries;
    constructor(props: P);
    /**
     * Gets whether or not this series is Category series
    */
    readonly isCategory: boolean;
    /**
     * Gets or sets whether this category series should allow custom style overrides of its individual visuals.
    */
    isCustomCategoryStyleAllowed: boolean;
    /**
     * Gets or sets whether this category series should allow custom style overrides of its individual marker visuals.
    */
    isCustomCategoryMarkerStyleAllowed: boolean;
    /**
     * Sets or Gets whether to increase marker fidelity for extreme data shapes that have lots of Y variation over short X intervals.
    */
    useHighMarkerFidelity: boolean;
    /**
     * Gets or sets the method by which to animate the data into the chart when the chart data source is swapped.
     * Note: Transitions are not currently supported for stacked series.
    */
    transitionInMode: CategoryTransitionInMode;
    /**
     * Gets or sets whether the series should transition into the plot area when a new data source is assigned.
     * Note: Transitions are not currently supported for stacked series.
    */
    isTransitionInEnabled: boolean;
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    getCategoryWidth(): number;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
    /**
     * Gets the index of the item based on world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItemIndex(world: IgPoint): number;
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    */
    getExactItemIndex(world: IgPoint): number;
    private _assigningCategoryStyle;
    private _assigningCategoryStyle_wrapped;
    /**
     * Event raised when Assigning Category Style
    */
    protected assigningCategoryStyle: (s: IgrCategorySeries, e: AssigningCategoryStyleEventArgs) => void;
    private _assigningCategoryMarkerStyle;
    private _assigningCategoryMarkerStyle_wrapped;
    /**
     * Event raised when Assigning Category Marker Style
    */
    protected assigningCategoryMarkerStyle: (s: IgrCategorySeries, e: AssigningCategoryMarkerStyleEventArgs) => void;
}
export interface IIgrCategorySeriesProps extends IIgrMarkerSeriesProps {
    /**
     * Gets or sets whether this category series should allow custom style overrides of its individual visuals.
    */
    isCustomCategoryStyleAllowed?: boolean;
    /**
     * Gets or sets whether this category series should allow custom style overrides of its individual marker visuals.
    */
    isCustomCategoryMarkerStyleAllowed?: boolean;
    /**
     * Sets or Gets whether to increase marker fidelity for extreme data shapes that have lots of Y variation over short X intervals.
    */
    useHighMarkerFidelity?: boolean;
    /**
     * Gets or sets the method by which to animate the data into the chart when the chart data source is swapped.
     * Note: Transitions are not currently supported for stacked series.
    */
    transitionInMode?: CategoryTransitionInMode;
    /**
     * Gets or sets whether the series should transition into the plot area when a new data source is assigned.
     * Note: Transitions are not currently supported for stacked series.
    */
    isTransitionInEnabled?: boolean;
}
