import { IgRect } from "igniteui-react-core/ES2015/IgRect";
import { IgPoint } from "igniteui-react-core/ES2015/IgPoint";
import { ConsolidatedItemsPosition } from "./ConsolidatedItemsPosition";
import { IgrHorizontalAnchoredCategorySeries, IIgrHorizontalAnchoredCategorySeriesProps } from "./igr-horizontal-anchored-category-series";
import { ColumnSeries } from "./ColumnSeries";
/**
 * Represents a IgxDataChartComponent column series.
 * Compare values across categories by using vertical rectangles.Use it when the order of categories is not important or for displaying
 * item counts such as a histogram.
*/
export declare class IgrColumnSeries extends IgrHorizontalAnchoredCategorySeries<IIgrColumnSeriesProps> {
    protected createImplementation(): ColumnSeries;
    readonly i: ColumnSeries;
    constructor(props: IIgrColumnSeriesProps);
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    radiusX: number;
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    radiusY: number;
    /**
     * The positioning logic to use for columns which have been consolidated into a single visual element.
    */
    consolidatedColumnVerticalPosition: ConsolidatedItemsPosition;
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    getSeriesValueBoundingBox(world: IgPoint): IgRect;
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan(): number;
}
export interface IIgrColumnSeriesProps extends IIgrHorizontalAnchoredCategorySeriesProps {
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    radiusX?: number;
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    radiusY?: number;
    /**
     * The positioning logic to use for columns which have been consolidated into a single visual element.
    */
    consolidatedColumnVerticalPosition?: ConsolidatedItemsPosition;
}
