import * as React from 'react';
import { IgrAxis } from './igr-axis';
import { IgrSeries } from './igr-series';
import { GridMode } from './GridMode';
import { IgrSeriesViewer, IIgrSeriesViewerProps } from './igr-series-viewer';
import { XamDataChart } from './XamDataChart';
import { SeriesCollection } from './igr-series-collection';
import { AxisCollection } from './igr-axis-collection';
/**
 * Represents a chart area containing axes, series, an optional legend and other hosted content.
*/
export declare class IgrDataChart extends IgrSeriesViewer<IIgrDataChartProps> {
    contentAxes: IgrAxis[];
    contentSeries: IgrSeries[];
    private _height;
    private _width;
    height: string;
    private _updateContentChildren;
    protected getSeriesRef(child: any): void;
    private _contentChildren;
    private _contentChildrenActual;
    private _contentChildrenMap;
    private _contentChildrenUnresolved;
    private _childrenDiffer;
    private _getMainRef;
    private _elRef;
    render(): React.DetailedReactHTMLElement<{
        ref: (ref: any) => void;
        children: any;
    }, any>;
    protected _tooltipRef(t: any): void;
    componentDidMount(): void;
    width: string;
    /**
     * The series actually present in the chart. Do not directly modify this array.
     * This array's contents can be modified by causing React to reproject the child content.
     * Or adding and removing series from the manual series collection on the series property.
     */
    actualSeries: IgrSeries[];
    /**
     * The axes actually present in the chart. Do not directly modify this array.
     * This array's contents can be modified by causing React to reproject the child content.
     * Or adding and removing axes from the manual axes collection on the axes property.
     */
    actualAxes: IgrAxis[];
    private _container;
    private _series;
    /**
     * A collection or manually added series for the chart.
    */
    readonly series: SeriesCollection;
    private _axes;
    /**
     * A collection or manually added axes for the chart.
    */
    readonly axes: AxisCollection;
    constructor(props: IIgrDataChartProps);
    componentWillUnmount(): void;
    private _initialized;
    private _wrapper;
    protected createImplementation(): XamDataChart;
    private _chart;
    private _dataSource;
    dataSource: any;
    bindData(): void;
    private _axesAdapter;
    private _seriesAdapter;
    initializeContent(): void;
    private _ensureTooltipCreated;
    private _defaultTooltips;
    private _ensureDefaultTooltip;
    private _onDefaultTooltipsReady;
    private _activeTooltips;
    private _activeTooltipElements;
    private _currentTooltips;
    private _uniqueTooltipId;
    private createTooltip;
    private _updateTooltipState;
    readonly i: XamDataChart;
    /**
 * Gets or sets whether to use a square aspect ratio for the chart. This is locked to true for polar and radial charts.
*/
    isSquare: boolean;
    /**
     * A number between 0 and 1 determining the scale of the horizontal zoom.
     * This property is effectively a shortcut to the Width of the WindowRect property.
    */
    windowScaleHorizontal: number;
    /**
     * A number between 0 and 1 determining the scale of the vertical zoom.
     * This property is effectively a shortcut to the Height of the WindowRect property.
    */
    windowScaleVertical: number;
    /**
     * A number between 0 and 1 determining the scale of the horizontal zoom.
     * This property is effectively a shortcut to the Width of the ActualWindowRect property.
    */
    actualWindowScaleHorizontal: number;
    /**
     * A number between 0 and 1 determining the scale of the vertical zoom.
     * This property is effectively a shortcut to the Height of the ActualWindowRect property.
    */
    actualWindowScaleVertical: number;
    /**
     * Gets or sets horizontal zoomability of the current control
    */
    isHorizontalZoomEnabled: boolean;
    /**
     * Gets or sets vertical zoomability of the current control
    */
    isVerticalZoomEnabled: boolean;
    /**
     * Gets or sets how grid lines are rendered in relation to series.
    */
    gridMode: GridMode;
    /**
     * Gets or sets a value indicating whether grid and tick lines are aligned to device pixels.
    */
    alignsGridLinesToPixels: boolean;
    /**
     * Gets or sets the palette of brushes to use for coloring the chart series.
    */
    brushes: string[];
    /**
     * Gets or sets the MarkerBrushes property.
     * The brushes property defines the palette from which automatically assigned series brushes are selected.
    */
    markerBrushes: string[];
    /**
     * Gets or sets the palette of brushes to use for outlines on the chart series.
    */
    outlines: string[];
    /**
     * Gets or sets the MarkerOutlines property.
     * The brushes property defines the palette from which automatically assigned series brushes are selected.
    */
    markerOutlines: string[];
    /**
     * Gets or sets the DefaultAxisStroke property.
     * The DefaultAxisStroke property defines the brush which is used by the axes when no Axis.Stroke is set.
    */
    defaultAxisStroke: string;
    /**
     * Gets or sets the DefaultAxisMajorStroke property.
     * The DefaultAxisMajorStroke property defines the brush which is used by the axes when no Axis.MajorStroke is set.
    */
    defaultAxisMajorStroke: string;
    /**
     * Gets or sets the DefaultAxisMinorStroke property.
     * The DefaultAxisMinorStroke property defines the brush which is used by the axes when no Axis.MinorStroke is set.
    */
    defaultAxisMinorStroke: string;
    /**
     * Margin applied to the left of the plot area.
    */
    plotAreaMarginLeft: number;
    /**
     * Margin applied above the plot area.
    */
    plotAreaMarginTop: number;
    /**
     * Margin applied to the right of the plot area.
    */
    plotAreaMarginRight: number;
    /**
     * Margin applied below the plot area.
    */
    plotAreaMarginBottom: number;
    /**
 * Notifies the chart that the CSS styles in effect have been updated.

*/
    styleUpdated(): void;
    /**
     * Export serialized visual data.
    
    */
    exportSerializedVisualData(): string;
}
export interface IIgrDataChartProps extends IIgrSeriesViewerProps {
    width?: string;
    height?: string;
    /**
  * Gets or sets the data for the chart to use. This can be overriden at the series and axis level.
  */
    dataSource?: any[];
    /**
 * Gets or sets whether to use a square aspect ratio for the chart. This is locked to true for polar and radial charts.
*/
    isSquare?: boolean;
    /**
     * A number between 0 and 1 determining the scale of the horizontal zoom.
     * This property is effectively a shortcut to the Width of the WindowRect property.
    */
    windowScaleHorizontal?: number;
    /**
     * A number between 0 and 1 determining the scale of the vertical zoom.
     * This property is effectively a shortcut to the Height of the WindowRect property.
    */
    windowScaleVertical?: number;
    /**
     * A number between 0 and 1 determining the scale of the horizontal zoom.
     * This property is effectively a shortcut to the Width of the ActualWindowRect property.
    */
    actualWindowScaleHorizontal?: number;
    /**
     * A number between 0 and 1 determining the scale of the vertical zoom.
     * This property is effectively a shortcut to the Height of the ActualWindowRect property.
    */
    actualWindowScaleVertical?: number;
    /**
     * Gets or sets horizontal zoomability of the current control
    */
    isHorizontalZoomEnabled?: boolean;
    /**
     * Gets or sets vertical zoomability of the current control
    */
    isVerticalZoomEnabled?: boolean;
    /**
     * Gets or sets how grid lines are rendered in relation to series.
    */
    gridMode?: GridMode;
    /**
     * Gets or sets a value indicating whether grid and tick lines are aligned to device pixels.
    */
    alignsGridLinesToPixels?: boolean;
    /**
     * Gets or sets the palette of brushes to use for coloring the chart series.
    */
    brushes?: string[];
    /**
     * Gets or sets the MarkerBrushes property.
     * The brushes property defines the palette from which automatically assigned series brushes are selected.
    */
    markerBrushes?: string[];
    /**
     * Gets or sets the palette of brushes to use for outlines on the chart series.
    */
    outlines?: string[];
    /**
     * Gets or sets the MarkerOutlines property.
     * The brushes property defines the palette from which automatically assigned series brushes are selected.
    */
    markerOutlines?: string[];
    /**
     * Gets or sets the DefaultAxisStroke property.
     * The DefaultAxisStroke property defines the brush which is used by the axes when no Axis.Stroke is set.
    */
    defaultAxisStroke?: string;
    /**
     * Gets or sets the DefaultAxisMajorStroke property.
     * The DefaultAxisMajorStroke property defines the brush which is used by the axes when no Axis.MajorStroke is set.
    */
    defaultAxisMajorStroke?: string;
    /**
     * Gets or sets the DefaultAxisMinorStroke property.
     * The DefaultAxisMinorStroke property defines the brush which is used by the axes when no Axis.MinorStroke is set.
    */
    defaultAxisMinorStroke?: string;
    /**
     * Margin applied to the left of the plot area.
    */
    plotAreaMarginLeft?: number;
    /**
     * Margin applied above the plot area.
    */
    plotAreaMarginTop?: number;
    /**
     * Margin applied to the right of the plot area.
    */
    plotAreaMarginRight?: number;
    /**
     * Margin applied below the plot area.
    */
    plotAreaMarginBottom?: number;
}
