import { FinalValueSelectionMode_$type } from "./FinalValueSelectionMode";
import { IgrAnnotationLayer } from "./igr-annotation-layer";
import { FinalValueLayer } from "./FinalValueLayer";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-react-core/ES2015/componentUtil";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
export class IgrFinalValueLayer extends IgrAnnotationLayer {
    createImplementation() {
        return new FinalValueLayer();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
    */
    get targetSeries() {
        if (this.i.ms == null) {
            return null;
        }
        return this.i.ms.externalObject;
    }
    set targetSeries(v) {
        v == null ? this.i.ms = null : this.i.ms = v.i;
    }
    /**
     * Gets or sets how to select the final value to annotate.
    */
    get finalValueSelectionMode() {
        return this.i.mr;
    }
    set finalValueSelectionMode(v) {
        this.i.mr = ensureEnum(FinalValueSelectionMode_$type, v);
    }
    /**
     * Gets or sets the color to use for the axis annotation text. Leave unset for an automatic value.
    */
    get axisAnnotationTextColor() {
        return brushToString(this.i.ni);
    }
    set axisAnnotationTextColor(v) {
        this.i.ni = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the axis annotation backing. Leave unset for an automatic value.
    */
    get axisAnnotationBackground() {
        return brushToString(this.i.ng);
    }
    set axisAnnotationBackground(v) {
        this.i.ng = stringToBrush(v);
    }
    /**
     * Gets or sets the precision to use displaying values for interpolated crosshair positions.
    */
    get axisAnnotationInterpolatedValuePrecision() {
        return this.i.mx;
    }
    set axisAnnotationInterpolatedValuePrecision(v) {
        this.i.mx = +v;
    }
    /**
     * Gets or sets the color to use for the axis annotation outline. Leave unset for an automatic value.
    */
    get axisAnnotationOutline() {
        return brushToString(this.i.nh);
    }
    set axisAnnotationOutline(v) {
        this.i.nh = stringToBrush(v);
    }
    /**
     * Gets or sets the padding for the axis annotation backing. Leave unset for an automatic value.
    */
    get axisAnnotationPadding() {
        return this.i.mv;
    }
    set axisAnnotationPadding(v) {
        this.i.mv = +v;
    }
    /**
     * Gets or sets the stroke thickness for the axis annotation backing. Leave unset for an automatic value.
    */
    get axisAnnotationStrokeThickness() {
        return this.i.mw;
    }
    set axisAnnotationStrokeThickness(v) {
        this.i.mw = +v;
    }
}
