import { IgrFinancialSeries, IIgrFinancialSeriesProps } from "./igr-financial-series";
import { FinancialOverlay } from "./FinancialOverlay";
/**
 * Represents the base functionality for a IgxDataChartComponent financial overlay series.
 * The difference between a FinancialIndicator and a FinancialOverlay is small.
 * Overlays are usually drawn against the same axes as the price, but they don't
 * have to be. Overlays mostly display multiple values, but not all of them, and so
 * so some indicators.
*/
export declare abstract class IgrFinancialOverlay<P extends IIgrFinancialOverlayProps = IIgrFinancialOverlayProps> extends IgrFinancialSeries<P> {
    readonly i: FinancialOverlay;
    constructor(props: P);
    /**
     * Gets or sets the number of values to hide at the beginning of the indicator.
    */
    ignoreFirst: number;
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    scrollIntoView(item: any): boolean;
}
export interface IIgrFinancialOverlayProps extends IIgrFinancialSeriesProps {
    /**
     * Gets or sets the number of values to hide at the beginning of the indicator.
    */
    ignoreFirst?: number;
}
