import { MarkerType_$type } from "./MarkerType";
import { IgrSeries } from "./igr-series";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-react-core/ES2015/componentUtil";
/**
 * Represents the base class for series containing markers.
*/
export class IgrMarkerSeries extends IgrSeries {
    constructor(props) {
        super(props);
    }
    get i() {
        return this._implementation;
    }
    /**
     * Returns whether the current series supports visual markers.
    */
    get hasMarkers() {
        return this.i.hasMarkers;
    }
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    get markerType() {
        return this.i.lp;
    }
    set markerType(v) {
        this.i.lp = ensureEnum(MarkerType_$type, v);
    }
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    get markerTemplate() {
        return this.i.l8;
    }
    set markerTemplate(v) {
        this.i.l8 = v;
    }
    /**
     * Gets the effective marker template for the current series object.
    */
    get actualMarkerTemplate() {
        return this.i.l6;
    }
    set actualMarkerTemplate(v) {
        this.i.l6 = v;
    }
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    get markerBrush() {
        return brushToString(this.i.ml);
    }
    set markerBrush(v) {
        this.i.ml = stringToBrush(v);
    }
    /**
     * Gets the effective marker brush for the current series object.
    */
    get actualMarkerBrush() {
        return brushToString(this.i.mj);
    }
    set actualMarkerBrush(v) {
        this.i.mj = stringToBrush(v);
    }
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    get markerOutline() {
        return brushToString(this.i.mm);
    }
    set markerOutline(v) {
        this.i.mm = stringToBrush(v);
    }
    /**
     * Gets the effective marker outline for the current series object.
    */
    get actualMarkerOutline() {
        return brushToString(this.i.mk);
    }
    set actualMarkerOutline(v) {
        this.i.mk = stringToBrush(v);
    }
}
