import { IgrAxis, IIgrAxisProps } from "./igr-axis";
import { NumericAxisBase } from "./NumericAxisBase";
/**
 * Represents the base class for all IgxDataChartComponent numeric axes.
*/
export declare abstract class IgrNumericAxisBase<P extends IIgrNumericAxisBaseProps = IIgrNumericAxisBaseProps> extends IgrAxis<P> {
    readonly i: NumericAxisBase;
    constructor(props: P);
    /**
     * Gets or sets if the current axis is of numeric axis type
    */
    readonly isNumeric: boolean;
    /**
     * Gets or sets the MinimumValue property.
    */
    minimumValue: number;
    /**
     * Gets the effective minimum value for the current numeric axis object.
    */
    actualMinimumValue: number;
    /**
     * Gets the effective minimum value for the current numeric axis object.
    */
    actualVisibleMinimumValue: number;
    /**
     * Gets or sets the MaximumValue property.
    */
    maximumValue: number;
    /**
     * Gets the effective maximum value for the current numeric axis object.
    */
    actualMaximumValue: number;
    /**
     * Gets the effective visible maximum value for the current numeric axis object.
    */
    actualVisibleMaximumValue: number;
    /**
     * Gets or sets the Interval property.
    */
    interval: number;
    /**
     * Gets the effective value for the current Interval.
    */
    actualInterval: number;
    /**
     * Gets or sets the MinorInterval property.
    */
    minorInterval: number;
    /**
     * Gets the effective value for the current MinorInterval.
    */
    actualMinorInterval: number;
    /**
     * Gets or sets the ReferenceValue property.
    */
    referenceValue: number;
    /**
     * Gets or sets the IsLogarithmic property.
    */
    isLogarithmic: boolean;
    /**
     * Determines if the axis has a valid logarithmic scale.
    */
    actualIsLogarithmic: boolean;
    /**
     * Gets or sets the LogarithmBase property.
    */
    logarithmBase: number;
    /**
     * Determines if the axis has a user-defined minimum.
    */
    readonly hasUserMinimum: boolean;
    /**
     * Determines if the axis has a user-defined maximum.
    */
    readonly hasUserMaximum: boolean;
    abbreviateLargeNumbers: boolean;
    /**
     * Unscales a value from screen space into axis space.
    
    * @param unscaledValue  * The scaled value in screen coordinates to unscale into axis space.
    */
    unscaleValue(unscaledValue: number): number;
}
export interface IIgrNumericAxisBaseProps extends IIgrAxisProps {
    /**
     * Gets or sets the MinimumValue property.
    */
    minimumValue?: number;
    /**
     * Gets the effective minimum value for the current numeric axis object.
    */
    actualMinimumValue?: number;
    /**
     * Gets the effective minimum value for the current numeric axis object.
    */
    actualVisibleMinimumValue?: number;
    /**
     * Gets or sets the MaximumValue property.
    */
    maximumValue?: number;
    /**
     * Gets the effective maximum value for the current numeric axis object.
    */
    actualMaximumValue?: number;
    /**
     * Gets the effective visible maximum value for the current numeric axis object.
    */
    actualVisibleMaximumValue?: number;
    /**
     * Gets or sets the Interval property.
    */
    interval?: number;
    /**
     * Gets the effective value for the current Interval.
    */
    actualInterval?: number;
    /**
     * Gets or sets the MinorInterval property.
    */
    minorInterval?: number;
    /**
     * Gets the effective value for the current MinorInterval.
    */
    actualMinorInterval?: number;
    /**
     * Gets or sets the ReferenceValue property.
    */
    referenceValue?: number;
    /**
     * Gets or sets the IsLogarithmic property.
    */
    isLogarithmic?: boolean;
    /**
     * Determines if the axis has a valid logarithmic scale.
    */
    actualIsLogarithmic?: boolean;
    /**
     * Gets or sets the LogarithmBase property.
    */
    logarithmBase?: number;
    abbreviateLargeNumbers?: boolean;
}
