import { IgrNumericAxisBase } from "./igr-numeric-axis-base";
import { NumericRadiusAxis } from "./NumericRadiusAxis";
/**
 * Represents a IgxDataChartComponent radius axis for polar and radial series.
*/
export class IgrNumericRadiusAxis extends IgrNumericAxisBase {
    createImplementation() {
        return new NumericRadiusAxis();
    }
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Checks if the axis is of radial axis type
    */
    get isRadial() {
        return this.i.cb;
    }
    /**
     * Defines the percentage of the maximum radius extent to use as the maximum radius. Should be
     * a value between 0.0 and 1.0.
    */
    get radiusExtentScale() {
        return this.i.ll;
    }
    set radiusExtentScale(v) {
        this.i.ll = +v;
    }
    /**
     * Defines the percentage of the maximum radius extent to leave blank at the center of the chart. Should be
     * a value between 0.0 and 1.0.
    */
    get innerRadiusExtentScale() {
        return this.i.lk;
    }
    set innerRadiusExtentScale(v) {
        this.i.lk = +v;
    }
    /**
     * Returns a world coordinates radius length (0 - 0.5) from a raw axis value.
    
    * @param unscaledValue  * The raw axis value.
    */
    getScaledValue(unscaledValue) {
        let iv = this.i.lh(unscaledValue);
        return (iv);
    }
    /**
     * Returns a raw axis value from the world coordinates radius length provided.
    
    * @param scaledValue  * The scaled world coordinates radius length.
    */
    getUnscaledValue(scaledValue) {
        let iv = this.i.lj(scaledValue);
        return (iv);
    }
}
