import * as React from 'react';
import { Visibility } from "igniteui-react-core/ES2015/Visibility";
import { IgRect } from "igniteui-react-core/ES2015/IgRect";
import { IgPoint } from "igniteui-react-core/ES2015/IgPoint";
import { IgDataTemplate } from "igniteui-react-core/ES2015/IgDataTemplate";
import { TransitionInSpeedType } from './TransitionInSpeedType';
import { SeriesHitTestMode } from './SeriesHitTestMode';
import { IgrAxis } from './igr-axis';
import { Series } from './Series';
import { RenderRequestedEventArgs } from './RenderRequestedEventArgs';
import { IChartTooltipProps } from "igniteui-react-core/ES2015/igr-chart-tooltip-props";
/**
 * Represents the base class for all IgxDataChartComponent series.
*/
export declare abstract class IgrSeries<P extends IIgrSeriesProps = IIgrSeriesProps> extends React.Component<P, {}> {
    protected _implementation: any;
    readonly i: Series;
    private onImplementationCreated;
    protected createImplementation(): Series;
    constructor(props: P);
    protected initializeProperties(): void;
    componentDidMount(): void;
    readonly seriesInternal: any;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): any;
    protected name: string;
    private _chartLevelData;
    provideData(data: any[]): void;
    private updateDataSource;
    private _dataSource;
    protected dataSource: any;
    bindAxes(axes: IgrAxis[]): void;
    private _tooltipTemplate;
    private _tooltipContent;
    tooltipTemplate: React.SFC<IChartTooltipProps> | React.Component<IChartTooltipProps>;
    private _tooltipContainerTemplate;
    tooltipContainerTemplate: React.SFC<IChartTooltipProps> | React.Component<IChartTooltipProps>;
    private _ensureTooltipCreated;
    private _ensureTooltipDestroyed;
    private _renderer;
    private _provideRenderer;
    static _createFromInternal(internal: any): IgrSeries;
    /**
 * Gets whether the series is an annotation layer.
*/
    readonly isAnnotationLayer: boolean;
    /**
     * Gets whether the current series is oriented vertically.
    */
    readonly isVertical: boolean;
    /**
     * Gets whether the current series is a stack fragment.
    */
    readonly isFragment: boolean;
    /**
     * Gets whether the current series shows an area or line shape.
    */
    readonly isAreaOrLine: boolean;
    /**
     * Gets whether the current series is a polar type series.
    */
    readonly isPolar: boolean;
    /**
     * Gets whether the current series is a scatter type series.
    */
    readonly isScatter: boolean;
    /**
     * Gets whether the current series is a radial type series.
    */
    readonly isRadial: boolean;
    /**
     * Gets whether the current series is a stacked type series.
    */
    readonly isStacked: boolean;
    /**
     * Gets whether the current series is a financial type series.
    */
    readonly isFinancial: boolean;
    /**
     * Gets whether the current series is a range type series.
    */
    readonly isRange: boolean;
    /**
     * Gets whether the current series is a category type series.
    */
    readonly isCategory: boolean;
    /**
     * Gets whether the current seires is a geogrpahic series.
    */
    readonly isGeographic: boolean;
    /**
     * Gets whether the default crosshair behavior should be disabled if this series is present.
    */
    readonly isDefaultCrosshairBehaviorDisabled: boolean;
    /**
     * Gets whether the default tooltip behavior should be disabled if this series is present.
    */
    readonly isDefaultTooltipBehaviorDisabled: boolean;
    /**
     * Returns whether the current series supports visual markers.
    */
    readonly hasMarkers: boolean;
    /**
     * Gets if the series uses an index, which can be used to auto-assign it a color.
    */
    readonly isIndexed: boolean;
    /**
     * Gets if the series should appear in any legends.
    */
    readonly isUsableInLegend: boolean;
    /**
     * Gets or sets the legend item visibility for the current series object.
    */
    legendItemVisibility: Visibility;
    /**
     * Gets or sets the LegendItemBadgeTemplate property.
     * The legend item badge is created according to the LegendItemBadgeTemplate on-demand by
     * the series object itself.
    */
    legendItemBadgeTemplate: IgDataTemplate;
    /**
     * Gets or sets the LegendItemTemplate property.
     * The legend item control content is created according to the LegendItemTemplate on-demand by
     * the series object itself.
    */
    legendItemTemplate: IgDataTemplate;
    /**
     * Gets or sets the DiscreteLegendItemTemplate property.
     * The legend item control content is created according to the DiscreteLegendItemTemplate on-demand by
     * the series object itself.
    */
    discreteLegendItemTemplate: IgDataTemplate;
    /**
     * Gets or sets the easing function used to morph the current series.
    */
    transitionEasingFunction: (time: number) => number;
    /**
     * Gets or sets the EasingFunction used to morph the current series during the initial transition.
    */
    transitionInEasingFunction: (time: number) => number;
    /**
     * Gets or sets the duration of the current series's morph.
    */
    transitionDuration: number;
    /**
     * Gets or sets the current series object's rendering resolution.
    */
    resolution: number;
    /**
     * Gets or sets the Title property.
     * The legend item control is created according to the Title on-demand by
     * the series object itself.
    */
    title: any;
    /**
     * Gets or sets the brush to use for the series.
    */
    brush: string;
    /**
     * Gets the effective brush for the current series object.
    */
    actualBrush: string;
    /**
     * Gets or sets the brush to use for the outline of the series.
     * Some series types, such as LineSeries, do not display outlines.  Therefore, this property does not affect some charts.
    */
    outline: string;
    /**
     * Gets the effective outline for the current series object.
    */
    actualOutline: string;
    /**
     * Gets or sets the width of the current series object's line thickness.
    */
    thickness: number;
    /**
     * Gets or sets whether highlighting should be enabled for this series, if this type of series supports highlighting.
    */
    isHighlightingEnabled: boolean;
    /**
     * Gets or sets whether drop shadow should be enabled for this series.
    */
    isDropShadowEnabled: boolean;
    /**
     * Gets or sets the shadow blur.
     * This property is ignored when Series.UseSingleShadow is set to true.
    */
    shadowBlur: number;
    /**
     * Gets or sets the drop shadow color.
    */
    shadowColor: string;
    /**
     * Gets or sets whether drop shadow is applied to the whole series visual or to each of the individual shapes forming the series.
     * When this property is set to true, no Series.ShadowBlur is applied.
    */
    useSingleShadow: boolean;
    /**
     * Gets or sets the drop shadow x-offset.
    */
    shadowOffsetX: number;
    /**
     * Gets or sets the drop shadow y-offset.
    */
    shadowOffsetY: number;
    /**
     * Gets or sets the opacity applied to the area fill visual.
     * This property only applies to series that have area visual.
    */
    areaFillOpacity: number;
    /**
     * Gets the actual opacity applied to the area fill visual.
    */
    actualAreaFillOpacity: number;
    /**
     * Gets if the default tooltip has been selected for display.
    */
    isDefaultToolTipSelected: boolean;
    /**
     * Gets or sets whether default tooltip will be shown.
    */
    showDefaultTooltip: boolean;
    /**
     * Gets or sets the duration of the current series's transition in morph.
    */
    transitionInDuration: number;
    /**
     * Gets or sets the duration of the current series's transition in morph.
    */
    transitionInSpeedType: TransitionInSpeedType;
    /**
     * Gets or sets the whether the chart reacts to mouse move events.
    */
    mouseOverEnabled: boolean;
    /**
     * Gets or gets the coercion methods to use when loading data from data sources.
     * Should be specified before setting any member paths, if being used. Setting it later
     * will not cause data to be reimported into the chart.
    */
    coercionMethods: any;
    /**
     * Gets or sets whether the series should expect that properties in its items source may be functions that need to be
     * evaluated to yield their value. This defaults to false, as there will be a subtle performance impact to using this feature.
     * This value must be set before assigning an item's source to take effect.
    */
    expectFunctions: boolean;
    /**
     * Method of hit testing to use when pointing to items in this series.
    */
    hitTestMode: SeriesHitTestMode;
    /**
     * Resolved method of hit testing to use when pointing to items in the chart.
    */
    actualHitTestMode: SeriesHitTestMode;
    readonly isNegativeColorSupported: boolean;
    readonly isMarkerlessDisplayPreferred: boolean;
    finalValue: number;
    percentChange: number;
    resolveTooltipBrush(): string;
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    */
    getExactItemIndex(world: IgPoint): number;
    /**
     * Gets the item item index associated with the specified world position
    
    */
    getItemIndex(world: IgPoint): number;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
    getPreviousOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getNextOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getSeriesValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    getSeriesValueBoundingBox(world: IgPoint): IgRect;
    /**
     * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinates for which to get a value marker bounding box for
    */
    getSeriesValueMarkerBoundingBox(world: IgPoint): IgRect;
    getSeriesHighValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesHighValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesLowValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesLowValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesValuePositionFromSeriesPixel(mouse: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesValueFromSeriesPixel(mouse: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan(): number;
    /**
     * Converts a point from coordinates within the series plot area to a world position within axis space.
    
    * @param seriesPoint  * The pixel location within the plot area of the series.
    */
    toWorldPosition(seriesPoint: IgPoint): IgPoint;
    /**
     * Converts a point from world coordinates to coordinates within the viewport of the series.
    
    * @param world  * The world position from which to convert.
    */
    fromWorldPosition(world: IgPoint): IgPoint;
    /**
     * Requests that the provided item should be brought into view if possible.
    
    * @param item  * The item to attempt to bring into view.
    */
    scrollIntoView(item: any): boolean;
    /**
     * Renders the series.
    
    * @param animate  * True if the change should be animated.
    */
    renderSeries(animate: boolean): void;
    /**
     * Gets the effective viewport, adjusted to account for margins and other factors.
    
    */
    getEffectiveViewport(): IgRect;
    removeAllAlternateViews(): void;
    removeAlternateView(viewIdentifier: string): void;
    /**
     * Replays the assigned transition in animation, if any.
    
    */
    replayTransitionIn(): void;
    /**
     * Simulates a pointer hover over the series surface.
    
    * @param point  * The pointer position relative to the series viewport over which to hover.
    */
    simulateHover(point: IgPoint): void;
    styleUpdated(): void;
    setNegativeColors(negativeBrush: string, negativeOutline: string): void;
    /**
     * Moves the cursor point to the provided world position. Some series may react to the current cursor position.
    
    * @param point  * The cursor point, in world coordinates.
    */
    moveCursorPoint(point: IgPoint): void;
    private _renderRequested;
    private _renderRequested_wrapped;
    /**
     * This event is raised every time a render has been requested from a series.
    */
    protected renderRequested: (s: IgrSeries, e: RenderRequestedEventArgs) => void;
}
export interface IIgrSeriesProps {
    /**
     * Sets or gets a required unique name for the series.
     * */
    name: string;
    /**
 * Gets or sets the legend item visibility for the current series object.
*/
    legendItemVisibility?: Visibility;
    /**
     * Gets or sets the LegendItemBadgeTemplate property.
     * The legend item badge is created according to the LegendItemBadgeTemplate on-demand by
     * the series object itself.
    */
    legendItemBadgeTemplate?: IgDataTemplate;
    /**
     * Gets or sets the LegendItemTemplate property.
     * The legend item control content is created according to the LegendItemTemplate on-demand by
     * the series object itself.
    */
    legendItemTemplate?: IgDataTemplate;
    /**
     * Gets or sets the DiscreteLegendItemTemplate property.
     * The legend item control content is created according to the DiscreteLegendItemTemplate on-demand by
     * the series object itself.
    */
    discreteLegendItemTemplate?: IgDataTemplate;
    /**
     * Gets or sets the easing function used to morph the current series.
    */
    transitionEasingFunction?: (time: number) => number;
    /**
     * Gets or sets the EasingFunction used to morph the current series during the initial transition.
    */
    transitionInEasingFunction?: (time: number) => number;
    /**
     * Gets or sets the duration of the current series's morph.
    */
    transitionDuration?: number;
    /**
     * Gets or sets the current series object's rendering resolution.
    */
    resolution?: number;
    /**
     * Gets or sets the Title property.
     * The legend item control is created according to the Title on-demand by
     * the series object itself.
    */
    title?: any;
    /**
     * Gets or sets the brush to use for the series.
    */
    brush?: string;
    /**
     * Gets the effective brush for the current series object.
    */
    actualBrush?: string;
    /**
     * Gets or sets the brush to use for the outline of the series.
     * Some series types, such as LineSeries, do not display outlines.  Therefore, this property does not affect some charts.
    */
    outline?: string;
    /**
     * Gets the effective outline for the current series object.
    */
    actualOutline?: string;
    /**
     * Gets or sets the width of the current series object's line thickness.
    */
    thickness?: number;
    /**
     * Gets or sets whether highlighting should be enabled for this series, if this type of series supports highlighting.
    */
    isHighlightingEnabled?: boolean;
    /**
     * Gets or sets whether drop shadow should be enabled for this series.
    */
    isDropShadowEnabled?: boolean;
    /**
     * Gets or sets the shadow blur.
     * This property is ignored when Series.UseSingleShadow is set to true.
    */
    shadowBlur?: number;
    /**
     * Gets or sets the drop shadow color.
    */
    shadowColor?: string;
    /**
     * Gets or sets whether drop shadow is applied to the whole series visual or to each of the individual shapes forming the series.
     * When this property is set to true, no Series.ShadowBlur is applied.
    */
    useSingleShadow?: boolean;
    /**
     * Gets or sets the drop shadow x-offset.
    */
    shadowOffsetX?: number;
    /**
     * Gets or sets the drop shadow y-offset.
    */
    shadowOffsetY?: number;
    /**
     * Gets or sets the opacity applied to the area fill visual.
     * This property only applies to series that have area visual.
    */
    areaFillOpacity?: number;
    /**
     * Gets the actual opacity applied to the area fill visual.
    */
    actualAreaFillOpacity?: number;
    /**
     * Gets if the default tooltip has been selected for display.
    */
    isDefaultToolTipSelected?: boolean;
    /**
     * Gets or sets whether default tooltip will be shown.
    */
    showDefaultTooltip?: boolean;
    /**
     * Gets or sets the duration of the current series's transition in morph.
    */
    transitionInDuration?: number;
    /**
     * Gets or sets the duration of the current series's transition in morph.
    */
    transitionInSpeedType?: TransitionInSpeedType;
    /**
     * Gets or sets the whether the chart reacts to mouse move events.
    */
    mouseOverEnabled?: boolean;
    /**
     * Gets or gets the coercion methods to use when loading data from data sources.
     * Should be specified before setting any member paths, if being used. Setting it later
     * will not cause data to be reimported into the chart.
    */
    coercionMethods?: any;
    /**
     * Gets or sets whether the series should expect that properties in its items source may be functions that need to be
     * evaluated to yield their value. This defaults to false, as there will be a subtle performance impact to using this feature.
     * This value must be set before assigning an item's source to take effect.
    */
    expectFunctions?: boolean;
    /**
     * Method of hit testing to use when pointing to items in this series.
    */
    hitTestMode?: SeriesHitTestMode;
    /**
     * Resolved method of hit testing to use when pointing to items in the chart.
    */
    actualHitTestMode?: SeriesHitTestMode;
    finalValue?: number;
    percentChange?: number;
}
