import { IgRect } from "igniteui-react-core/ES2015/IgRect";
import { IgPoint } from "igniteui-react-core/ES2015/IgPoint";
import { IgrHorizontalAnchoredCategorySeries, IIgrHorizontalAnchoredCategorySeriesProps } from "./igr-horizontal-anchored-category-series";
import { WaterfallSeries } from "./WaterfallSeries";
/**
 * Represents a IgxDataChartComponent waterfall column series.
*/
export declare class IgrWaterfallSeries extends IgrHorizontalAnchoredCategorySeries<IIgrWaterfallSeriesProps> {
    protected createImplementation(): WaterfallSeries;
    readonly i: WaterfallSeries;
    constructor(props: IIgrWaterfallSeriesProps);
    readonly isNegativeColorSupported: boolean;
    /**
     * Gets or sets the brush to use for negative portions of the series.
    */
    negativeBrush: string;
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    radiusX: number;
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    radiusY: number;
    /**
     * Brush to use for outlining negative elements in the waterfall series.
    */
    negativeOutline: string;
    setNegativeColors(negativeBrush: string, negativeOutline: string): void;
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    getSeriesValueBoundingBox(world: IgPoint): IgRect;
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan(): number;
}
export interface IIgrWaterfallSeriesProps extends IIgrHorizontalAnchoredCategorySeriesProps {
    /**
     * Gets or sets the brush to use for negative portions of the series.
    */
    negativeBrush?: string;
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    radiusX?: number;
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    radiusY?: number;
    /**
     * Brush to use for outlining negative elements in the waterfall series.
    */
    negativeOutline?: string;
}
