import * as tslib_1 from "tslib";
import { TimeAxisDisplayType_$type } from "./TimeAxisDisplayType";
import { IgrTimeAxisBase } from "./igr-time-axis-base";
import { CategoryDateTimeXAxis } from "./CategoryDateTimeXAxis";
import { ensureEnum } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents a category-based horizontal X axis that uses a DateTime scale.
*/
var IgrCategoryDateTimeXAxis = /** @class */ (function (_super) {
    tslib_1.__extends(IgrCategoryDateTimeXAxis, _super);
    function IgrCategoryDateTimeXAxis(props) {
        return _super.call(this, props) || this;
    }
    IgrCategoryDateTimeXAxis.prototype.createImplementation = function () {
        return new CategoryDateTimeXAxis();
    };
    Object.defineProperty(IgrCategoryDateTimeXAxis.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryDateTimeXAxis.prototype, "isContinuous", {
        /**
         * Gets if the current axis is a continuous rather than a discrete scale
        */
        get: function () {
            return this.i.b4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryDateTimeXAxis.prototype, "displayType", {
        /**
         * Gets or sets the axis display type.
         * Continuous display type divides the axis into even intervals, where labels will not necessarily be aligned with data points.
         * Discrete display type will not use a constant interval, but will align each label with its data point.
        */
        get: function () {
            return this.i.lt;
        },
        set: function (v) {
            this.i.lt = ensureEnum(TimeAxisDisplayType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryDateTimeXAxis.prototype, "interval", {
        /**
         * Gets or sets the X axis time interval.
        */
        get: function () {
            return this.i.l3;
        },
        set: function (v) {
            this.i.l3 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryDateTimeXAxis.prototype, "actualInterval", {
        /**
         * Gets the effective value for the current Interval.
        */
        get: function () {
            return this.i.l0;
        },
        set: function (v) {
            this.i.l0 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryDateTimeXAxis.prototype, "minorInterval", {
        /**
         * Gets or sets the frequency of displayed minor lines.
         * The set value is a factor that determines how the minor lines will be displayed.
        */
        get: function () {
            return this.i.l4;
        },
        set: function (v) {
            this.i.l4 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryDateTimeXAxis.prototype, "actualMinorInterval", {
        /**
         * Gets the effective value for the current MinorInterval.
        */
        get: function () {
            return this.i.l1;
        },
        set: function (v) {
            this.i.l1 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryDateTimeXAxis.prototype, "isCategoryDateTime", {
        get: function () {
            return this.i.b3;
        },
        enumerable: true,
        configurable: true
    });
    IgrCategoryDateTimeXAxis.prototype.scrollIntoView = function (minimum, maximum) {
        this.i.ma(minimum, maximum);
    };
    return IgrCategoryDateTimeXAxis;
}(IgrTimeAxisBase));
export { IgrCategoryDateTimeXAxis };
