import { IgrCategoryAxisBase } from "./igr-category-axis-base";
import { IgrAnnotationLayer, IIgrAnnotationLayerProps } from "./igr-annotation-layer";
import { CategoryHighlightLayer } from "./CategoryHighlightLayer";
/**
 * Represents an annotation layer that targets a category axis, or all category axes in the chart.
 * If the axis contains any series that are aligned between major gridlines of the axis (column, waterfall, etc) this will render a shape that fills the current category.
 * Otherwise it will render a band with an adjustable thickness at the closest gridline to the pointer position.
 * Setting UseIterpolation to true will cause the x position in the latter case to become affixed to the x position of the pointer.
*/
export declare class IgrCategoryHighlightLayer extends IgrAnnotationLayer<IIgrCategoryHighlightLayerProps> {
    protected createImplementation(): CategoryHighlightLayer;
    readonly i: CategoryHighlightLayer;
    constructor(props: IIgrCategoryHighlightLayerProps);
    /**
     * Gets or sets the axis to target this annotation to. If null, this annotation targets all category axes simultaneously.
    */
    targetAxis: IgrCategoryAxisBase;
    /**
     * Gets or sets whether to use value interpolation when drawing a line through the best value for the pointer position.
    */
    useInterpolation: boolean;
    /**
     * Gets or sets the width to use for the highlight region if drawing a band rather than filling a category.
    */
    bandHighlightWidth: number;
}
export interface IIgrCategoryHighlightLayerProps extends IIgrAnnotationLayerProps {
    /**
     * Gets or sets the axis to target this annotation to. If null, this annotation targets all category axes simultaneously.
    */
    targetAxis?: IgrCategoryAxisBase;
    /**
     * Gets or sets whether to use value interpolation when drawing a line through the best value for the pointer position.
    */
    useInterpolation?: boolean;
    /**
     * Gets or sets the width to use for the highlight region if drawing a band rather than filling a category.
    */
    bandHighlightWidth?: number;
}
