import { IgRect } from "igniteui-react-core/ES5/IgRect";
import { IgPoint } from "igniteui-react-core/ES5/IgPoint";
import { IgrCategoryAxisBase } from './igr-category-axis-base';
import { IgrNumericYAxis } from './igr-numeric-y-axis';
import { IgrAnchoredCategorySeries, IIgrAnchoredCategorySeriesProps } from './igr-anchored-category-series';
import { IgrAxis } from './igr-axis';
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
/**
 * Base class for anchored category series with a category x-axis and a numeric y-axis.
*/
export declare abstract class IgrHorizontalAnchoredCategorySeries<P extends IIgrHorizontalAnchoredCategorySeriesProps = IIgrHorizontalAnchoredCategorySeriesProps> extends IgrAnchoredCategorySeries<P> {
    constructor(props: P);
    private _xAxisName;
    xAxisName: string;
    private _yAxisName;
    yAxisName: string;
    bindAxes(axes: IgrAxis[]): void;
    readonly i: HorizontalAnchoredCategorySeries;
    /**
 * Gets or sets the effective x-axis for this series.
*/
    xAxis: IgrCategoryAxisBase;
    /**
     * Gets or sets the effective y-axis for this series.
    */
    yAxis: IgrNumericYAxis;
    /**
 * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.

* @param world  * The world coordinates for which to get a value marker bounding box for
*/
    getSeriesValueMarkerBoundingBox(world: IgPoint): IgRect;
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    getCategoryWidth(): number;
    getSeriesValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getPreviousOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getNextOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getSeriesValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis: any): boolean;
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis: any): boolean;
}
export interface IIgrHorizontalAnchoredCategorySeriesProps extends IIgrAnchoredCategorySeriesProps {
    xAxisName?: string;
    yAxisName?: string;
    /**
 * Gets or sets the effective x-axis for this series.
*/
    xAxis?: IgrCategoryAxisBase;
    /**
     * Gets or sets the effective y-axis for this series.
    */
    yAxis?: IgrNumericYAxis;
}
