import { IgPoint } from "igniteui-react-core/ES5/IgPoint";
import { IgrCategoryAxisBase } from "./igr-category-axis-base";
import { IgrNumericYAxis } from "./igr-numeric-y-axis";
import { IgrRangeCategorySeries, IIgrRangeCategorySeriesProps } from "./igr-range-category-series";
import { HorizontalRangeCategorySeries } from "./HorizontalRangeCategorySeries";
/**
 * Base class for ranged category series with a category X-axis and a numeric Y-axis.
*/
export declare abstract class IgrHorizontalRangeCategorySeries<P extends IIgrHorizontalRangeCategorySeriesProps = IIgrHorizontalRangeCategorySeriesProps> extends IgrRangeCategorySeries<P> {
    readonly i: HorizontalRangeCategorySeries;
    constructor(props: P);
    /**
     * Gets or sets the effective x-axis for the current CategorySeries object.
    */
    xAxis: IgrCategoryAxisBase;
    /**
     * Gets or sets the effective y-axis for the current CategorySeries object.
    */
    yAxis: IgrNumericYAxis;
    /**
     * Checks if this series is a range series
    */
    readonly isRange: boolean;
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    getCategoryWidth(): number;
    getNextOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getPreviousOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getSeriesValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesLowValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesHighValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesHighValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesLowValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis: any): boolean;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis: any): boolean;
}
export interface IIgrHorizontalRangeCategorySeriesProps extends IIgrRangeCategorySeriesProps {
    /**
     * Gets or sets the effective x-axis for the current CategorySeries object.
    */
    xAxis?: IgrCategoryAxisBase;
    /**
     * Gets or sets the effective y-axis for the current CategorySeries object.
    */
    yAxis?: IgrNumericYAxis;
}
