import { IgDataTemplate } from "igniteui-react-core/ES5/IgDataTemplate";
import { MarkerType } from "./MarkerType";
import { IgrSeries, IIgrSeriesProps } from "./igr-series";
import { MarkerSeries } from "./MarkerSeries";
/**
 * Represents the base class for series containing markers.
*/
export declare abstract class IgrMarkerSeries<P extends IIgrMarkerSeriesProps = IIgrMarkerSeriesProps> extends IgrSeries<P> {
    readonly i: MarkerSeries;
    constructor(props: P);
    /**
     * Returns whether the current series supports visual markers.
    */
    readonly hasMarkers: boolean;
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    markerType: MarkerType;
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    markerTemplate: IgDataTemplate;
    /**
     * Gets the effective marker template for the current series object.
    */
    actualMarkerTemplate: IgDataTemplate;
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    markerBrush: string;
    /**
     * Gets the effective marker brush for the current series object.
    */
    actualMarkerBrush: string;
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    markerOutline: string;
    /**
     * Gets the effective marker outline for the current series object.
    */
    actualMarkerOutline: string;
}
export interface IIgrMarkerSeriesProps extends IIgrSeriesProps {
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    markerType?: MarkerType;
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    markerTemplate?: IgDataTemplate;
    /**
     * Gets the effective marker template for the current series object.
    */
    actualMarkerTemplate?: IgDataTemplate;
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    markerBrush?: string;
    /**
     * Gets the effective marker brush for the current series object.
    */
    actualMarkerBrush?: string;
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    markerOutline?: string;
    /**
     * Gets the effective marker outline for the current series object.
    */
    actualMarkerOutline?: string;
}
