import * as tslib_1 from "tslib";
import { MarkerType_$type } from "./MarkerType";
import { IgrSeries } from "./igr-series";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents the base class for series containing markers.
*/
var IgrMarkerSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrMarkerSeries, _super);
    function IgrMarkerSeries(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrMarkerSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "hasMarkers", {
        /**
         * Returns whether the current series supports visual markers.
        */
        get: function () {
            return this.i.hasMarkers;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "markerType", {
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
        get: function () {
            return this.i.lp;
        },
        set: function (v) {
            this.i.lp = ensureEnum(MarkerType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "markerTemplate", {
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
        get: function () {
            return this.i.l8;
        },
        set: function (v) {
            this.i.l8 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "actualMarkerTemplate", {
        /**
         * Gets the effective marker template for the current series object.
        */
        get: function () {
            return this.i.l6;
        },
        set: function (v) {
            this.i.l6 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "markerBrush", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
        get: function () {
            return brushToString(this.i.ml);
        },
        set: function (v) {
            this.i.ml = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "actualMarkerBrush", {
        /**
         * Gets the effective marker brush for the current series object.
        */
        get: function () {
            return brushToString(this.i.mj);
        },
        set: function (v) {
            this.i.mj = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "markerOutline", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
        get: function () {
            return brushToString(this.i.mm);
        },
        set: function (v) {
            this.i.mm = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrMarkerSeries.prototype, "actualMarkerOutline", {
        /**
         * Gets the effective marker outline for the current series object.
        */
        get: function () {
            return brushToString(this.i.mk);
        },
        set: function (v) {
            this.i.mk = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    return IgrMarkerSeries;
}(IgrSeries));
export { IgrMarkerSeries };
