import { IgrStrategyBasedIndicator, IIgrStrategyBasedIndicatorProps } from "./igr-strategy-based-indicator";
import { MovingAverageConvergenceDivergenceIndicator } from "./MovingAverageConvergenceDivergenceIndicator";
/**
 * Represents a IgxDataChartComponent Moving Average Convergence/Divergence (MACD) indicator series.
 * Default required members: High, Low, Close
*/
export declare class IgrMovingAverageConvergenceDivergenceIndicator extends IgrStrategyBasedIndicator<IIgrMovingAverageConvergenceDivergenceIndicatorProps> {
    protected createImplementation(): MovingAverageConvergenceDivergenceIndicator;
    readonly i: MovingAverageConvergenceDivergenceIndicator;
    constructor(props: IIgrMovingAverageConvergenceDivergenceIndicatorProps);
    /**
     * Gets or sets the short moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
     * The typical, and initial, value for short MACD periods is 10.
    */
    shortPeriod: number;
    /**
     * Gets or sets the long moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
     * The typical, and initial, value for long MACD periods is 30.
    */
    longPeriod: number;
    /**
     * Gets or sets the long moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
     * The typical, and initial, value for long PVO periods is 30.
    */
    signalPeriod: number;
}
export interface IIgrMovingAverageConvergenceDivergenceIndicatorProps extends IIgrStrategyBasedIndicatorProps {
    /**
     * Gets or sets the short moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
     * The typical, and initial, value for short MACD periods is 10.
    */
    shortPeriod?: number;
    /**
     * Gets or sets the long moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
     * The typical, and initial, value for long MACD periods is 30.
    */
    longPeriod?: number;
    /**
     * Gets or sets the long moving average period for the current MovingAverageConvergenceDivergenceIndicator object.
     * The typical, and initial, value for long PVO periods is 30.
    */
    signalPeriod?: number;
}
