import * as React from 'react';
import { IgRect } from "igniteui-react-core/ES5/IgRect";
import { IgPoint } from "igniteui-react-core/ES5/IgPoint";
import { ChartHitTestMode } from "./ChartHitTestMode";
import { WindowResponse } from "./WindowResponse";
import { Visibility } from "igniteui-react-core/ES5/Visibility";
import { InteractionState } from "igniteui-react-core/ES5/InteractionState";
import { ModifierKeys } from "igniteui-react-core/ES5/ModifierKeys";
import { HorizontalAlignment } from "igniteui-react-core/ES5/HorizontalAlignment";
import { ChartCursorEventArgs } from "./igr-chart-cursor-event-args";
import { DataChartMouseButtonEventArgs } from "./igr-data-chart-mouse-button-event-args";
import { ChartMouseEventArgs } from "./igr-chart-mouse-event-args";
import { RectChangedEventArgs } from "igniteui-react-core/ES5/igr-rect-changed-event-args";
import { IgrSeries } from "./igr-series";
import { SeriesViewer } from "./SeriesViewer";
/**
 * Represents a control for viewing series objects.
*/
export declare abstract class IgrSeriesViewer<P extends IIgrSeriesViewerProps = IIgrSeriesViewerProps> extends React.Component<P, {}> {
    protected createImplementation(): SeriesViewer;
    protected _implementation: any;
    readonly i: SeriesViewer;
    private onImplementationCreated;
    constructor(props: P);
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): any;
    /**
     * Gets or sets the cross hair point (in world coordinates)
     * Either or both of the crosshair point's X and Y may be set to double.NaN, in which
     * case the relevant crosshair line is hidden.
    */
    crosshairPoint: IgPoint;
    /**
     * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
    */
    animateSeriesWhenAxisRangeChanges: boolean;
    /**
     * Gets the viewport rectangle associated with the SeriesViewer, the physical dimensions of the plot area.
    */
    readonly viewportRect: IgRect;
    /**
     * Gets the EffectiveViewport rectangle, representing the effective viewport area after margins have been subtracted.
    */
    effectiveViewport: IgRect;
    /**
     * Represents the subset area within the viewport into which content should be mapped.
     * This is the projection of the current EffectiveViewport into the viewport at current zoom level.
    */
    readonly contentViewport: IgRect;
    /**
     * A rectangle representing the portion of the SeriesViewer currently in view.
     * A rectangle at X=0, Y=0 with a Height and Width of 1 implies the entire plotting area is in view.  A Height and Width of .5 would imply that the view is halfway zoomed in.
    */
    windowRect: IgRect;
    /**
     * Gets or sets whether the series viewer should use cached tiles during zooms rather than the default live content.
    */
    useTiledZooming: boolean;
    /**
     * Gets or sets whether the series viewer should prefer selecting higher resolution tiles over lower resolution tiles when performing tile zooming. Setting this to true will lower performance but increase quality.
    */
    preferHigherResolutionTiles: boolean;
    /**
     * Gets or sets the maximum number of zoom tiles that the series viewer should cache while in tiled zooming mode.
    */
    zoomTileCacheSize: number;
    /**
     * Gets or sets the duration the highlighting/de-highlighting effects.
    */
    highlightingTransitionDuration: number;
    /**
     * Gets or sets the whether the series viewer can allow the page to pan if a control pan is not possible in the requested direction.
    */
    isPagePanningAllowed: boolean;
    /**
     * Determines the method of hit testing used when mousing over elements in the chart.
    */
    contentHitTestMode: ChartHitTestMode;
    /**
     * Resolved method of hit testing used when the pointer is over elements in the chart.
    */
    actualContentHitTestMode: ChartHitTestMode;
    /**
     * Gets or sets whether all surface interactions with the plot area should be disabled.
    */
    isSurfaceInteractionDisabled: boolean;
    readonly isMap: boolean;
    /**
     * The response to user panning and zooming: whether to update the view immediately while the user action is happening, or to defer the update to after the user action is complete.  The user action will be an action such as a mouse drag which causes panning and/or zooming to occur.
    */
    windowResponse: WindowResponse;
    /**
     * Sets or gets the minimum width that the window rect is allowed to reach before being clamped.
     * Decrease this value if you want to allow for further zooming into the viewer.
     * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
    */
    windowRectMinWidth: number;
    /**
     * Sets or gets the Synchronization channel to use for the SeriesViewer.
    */
    syncChannel: string;
    /**
     * The visibility of the OverviewPlusDetailPane.
    */
    overviewPlusDetailPaneVisibility: Visibility;
    /**
     * Gets or sets the current SeriesViewer's crosshair visibility override.
    */
    crosshairVisibility: Visibility;
    /**
     * Gets or sets the brush used as the background for the current SeriesViewer object's plot area.
    */
    plotAreaBackground: string;
    /**
     * Gets or sets the DefaultInteraction property.
     * The default interaction state defines the SeriesViewer's response to mouse events.
    */
    defaultInteraction: InteractionState;
    /**
     * Gets or sets the current SeriesViewer's DragModifier property.
    */
    dragModifier: ModifierKeys;
    /**
     * Gets or sets the current SeriesViewer's PanModifier property.
    */
    panModifier: ModifierKeys;
    /**
     * Gets or sets the preview rectangle.
     * The preview rectangle may be set to Rect.Empty, in which case the visible preview
     * strokePath is hidden.
    */
    previewRect: IgRect;
    /**
     * A number between 0 and 1 determining the position of the horizontal scroll.
     * This property is effectively a shortcut to the X position of the WindowRect property.
    */
    windowPositionHorizontal: number;
    /**
     * A number between 0 and 1 determining the position of the vertical scroll.
     * This property is effectively a shortcut to the Y position of the WindowRect property.
    */
    windowPositionVertical: number;
    /**
     * Text to display above the plot area.
    */
    chartTitle: string;
    /**
     * Gets or sets the TitleHorizontalAlignment property.
    */
    titleHorizontalAlignment: HorizontalAlignment;
    /**
     * Gets or sets the SubtitleHorizontalAlignment property.
    */
    subtitleHorizontalAlignment: HorizontalAlignment;
    titleTextStyle: string;
    subtitleTextStyle: string;
    /**
     * Gets or sets the Color used for the Title Text.
    */
    titleTextColor: string;
    /**
     * Gets or sets the Color used for the Subtitle Text.
    */
    subtitleTextColor: string;
    /**
     * Margin applied above the title.
    */
    titleTopMargin: number;
    /**
     * Margin applied to the left of the title.
    */
    titleLeftMargin: number;
    /**
     * Margin applied to the right of the title.
    */
    titleRightMargin: number;
    /**
     * Margin applied below the title.
    */
    titleBottomMargin: number;
    /**
     * Margin applied above the subtitle.
    */
    subtitleTopMargin: number;
    /**
     * Margin applied to the left of the subtitle.
    */
    subtitleLeftMargin: number;
    /**
     * Margin applied to the right of the subtitle.
    */
    subtitleRightMargin: number;
    /**
     * Margin applied below the subtitle.
    */
    subtitleBottomMargin: number;
    /**
     * Gets or sets the Subtitle property.
     * The Title property defines the Subtitle of the chart
    */
    subtitle: string;
    /**
     * Gets or sets the channel with which to synchronize.
    */
    SyncChannel: string;
    /**
     * Gets or sets the bool used to display the window preview shadow.
    */
    SynchronizeVertically: boolean;
    /**
     * Gets or sets the bool used to display the window preview shadow.
    */
    SynchronizeHorizontally: boolean;
    ensureSyncSettings(): void;
    /**
     * Sets or gets the top margin to use around the chart content.
    */
    topMargin: number;
    /**
     * Sets or gets the left margin to use around the chart content.
    */
    leftMargin: number;
    /**
     * Sets or gets the right margin to use around the chart content.
    */
    rightMargin: number;
    /**
     * Sets or gets the bottom margin to use around the chart content.
    */
    bottomMargin: number;
    /**
     * Sets or gets the automatic width to add when automatically adding margins to the chart.
    */
    autoMarginWidth: number;
    /**
     * Sets or gets the automatic height to add when automatically adding margins to the chart.
    */
    autoMarginHeight: number;
    /**
     * Gets or sets the IsAntiAliasingEnabledDuringInteraction property.
    */
    isAntiAliasingEnabledDuringInteraction: boolean;
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    pixelScalingRatio: number;
    /**
     * Method of pixel scaling to use during end user interaction with the chart.
    */
    interactionPixelScalingRatio: number;
    /**
     * Uri for the background image to display behind the overview plus detail pane.
    */
    overviewPlusDetailPaneBackgroundImageUri: string;
    /**
     * Gets the resolved pixel scaling ratio.
    */
    actualPixelScalingRatio: number;
    /**
     * Resolved method of pixel scaling to use during end user interaction with the chart.
    */
    actualInteractionPixelScalingRatio: number;
    /**
     * Gets the actual value of the window rectangle, which represents the current zoom level.
    */
    actualWindowRect: IgRect;
    /**
     * A number between 0 and 1 determining the position of the horizontal scroll.
     * This property is effectively a shortcut to the Left of the ActualWindowRect property.
    */
    actualWindowPositionHorizontal: number;
    /**
     * A number between 0 and 1 determining the position of the vertical scroll.
     * This property is effectively a shortcut to the Top of the ActualWindowRect property.
    */
    actualWindowPositionVertical: number;
    /**
     * Hides the active main tooltip, if displayed.
    
    */
    hideToolTip(): void;
    /**
     * Manually starts a tiled zoom if one isn't already running.
    
    */
    startTiledZoomingIfNecessary(): void;
    /**
     * Manually ends a tiled zoom if one is running.
    
    */
    endTiledZoomingIfRunning(): void;
    /**
     * Clears the tile zoom tile cache so that new tiles will be generated. Only applies if the viewer is using a tile based zoom.
    
    */
    clearTileZoomCache(): void;
    /**
     * Resets the zoom level to default.
    
    */
    resetZoom(): void;
    /**
     * Gets actual window scale for horizontal dimension of the control
    
    */
    getActualWindowScaleHorizontal(): number;
    /**
     * Gets actual window scale for vertical dimension of the control
    
    */
    getActualWindowScaleVertical(): number;
    /**
     * Notification from the containing object that the container has been resized.
    
    */
    notifyContainerResized(): void;
    /**
     * Attaches the given series to the chart.
    
    * @param s  * The series to attach to the chart.
    */
    attachSeries(s: IgrSeries): void;
    notifySetItem(source_: any, index: number, oldItem: any, newItem: any): void;
    /**
     * Used to manually notify the SeriesViewer that the data source has reset or cleared its items.  Invoking this method is only necessary if that datasource is not observable.
    
    * @param source_  * The data source which was cleared or reset.
    */
    notifyClearItems(source_: any): void;
    notifyInsertItem(source_: any, index: number, newItem: any): void;
    notifyRemoveItem(source_: any, index: number, oldItem: any): void;
    /**
     * Release any resources held by the control.
    
    */
    destroy(): void;
    /**
     * Use to force the SeriesViewer to finish any deferred work before printing or evaluating its visual.
     * This should only be called if the visual of the SeriesViewer needs to be synchronously saved or evaluated.
     * Calling this method too often will hinder the performance of the SeriesViewer.
    
    */
    flush(): void;
    private _seriesCursorMouseMove;
    private _seriesCursorMouseMove_wrapped;
    /**
     * Occurs when the cursors are moved over a series in this SeriesViewer.
    */
    protected seriesCursorMouseMove: (s: IgrSeriesViewer, e: ChartCursorEventArgs) => void;
    private _seriesMouseLeftButtonDown;
    private _seriesMouseLeftButtonDown_wrapped;
    /**
     * Occurs when the left mouse button is pressed while the mouse pointer is over a Series.
    */
    protected seriesMouseLeftButtonDown: (s: IgrSeriesViewer, e: DataChartMouseButtonEventArgs) => void;
    private _seriesMouseLeftButtonUp;
    private _seriesMouseLeftButtonUp_wrapped;
    /**
     * Occurs when the left mouse button is released while the mouse pointer is over a Series.
    */
    protected seriesMouseLeftButtonUp: (s: IgrSeriesViewer, e: DataChartMouseButtonEventArgs) => void;
    private _seriesMouseMove;
    private _seriesMouseMove_wrapped;
    /**
     * Occurs when the mouse pointer moves while over a Series.
    */
    protected seriesMouseMove: (s: IgrSeriesViewer, e: ChartMouseEventArgs) => void;
    private _seriesMouseEnter;
    private _seriesMouseEnter_wrapped;
    /**
     * Occurs when the mouse pointer enters a Series.
    */
    protected seriesMouseEnter: (s: IgrSeriesViewer, e: ChartMouseEventArgs) => void;
    private _seriesMouseLeave;
    private _seriesMouseLeave_wrapped;
    /**
     * Occurs when the mouse pointer leaves a Series.
    */
    protected seriesMouseLeave: (s: IgrSeriesViewer, e: ChartMouseEventArgs) => void;
    private _windowRectChanged;
    private _windowRectChanged_wrapped;
    /**
     * Occurs just after the current SeriesViewer's window rectangle is changed.
    */
    protected windowRectChanged: (s: IgrSeriesViewer, e: RectChangedEventArgs) => void;
    private _sizeChanged;
    private _sizeChanged_wrapped;
    /**
     * Occurs after the size of the series viewer changes.
    */
    protected sizeChanged: (s: IgrSeriesViewer, e: RectChangedEventArgs) => void;
    private _gridAreaRectChanged;
    private _gridAreaRectChanged_wrapped;
    /**
     * Occurs just after the current SeriesViewer's grid area rectangle is changed.
     * The grid area may change as the result of the SeriesViewer being resized, or
     * of an axis being added or changing size, possibly in another SeriesViewer.
    */
    protected gridAreaRectChanged: (s: IgrSeriesViewer, e: RectChangedEventArgs) => void;
}
export interface IIgrSeriesViewerProps {
    /**
     * Gets or sets the cross hair point (in world coordinates)
     * Either or both of the crosshair point's X and Y may be set to double.NaN, in which
     * case the relevant crosshair line is hidden.
    */
    crosshairPoint?: IgPoint;
    /**
     * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
    */
    animateSeriesWhenAxisRangeChanges?: boolean;
    /**
     * Gets the EffectiveViewport rectangle, representing the effective viewport area after margins have been subtracted.
    */
    effectiveViewport?: IgRect;
    /**
     * A rectangle representing the portion of the SeriesViewer currently in view.
     * A rectangle at X=0, Y=0 with a Height and Width of 1 implies the entire plotting area is in view.  A Height and Width of .5 would imply that the view is halfway zoomed in.
    */
    windowRect?: IgRect;
    /**
     * Gets or sets whether the series viewer should use cached tiles during zooms rather than the default live content.
    */
    useTiledZooming?: boolean;
    /**
     * Gets or sets whether the series viewer should prefer selecting higher resolution tiles over lower resolution tiles when performing tile zooming. Setting this to true will lower performance but increase quality.
    */
    preferHigherResolutionTiles?: boolean;
    /**
     * Gets or sets the maximum number of zoom tiles that the series viewer should cache while in tiled zooming mode.
    */
    zoomTileCacheSize?: number;
    /**
     * Gets or sets the duration the highlighting/de-highlighting effects.
    */
    highlightingTransitionDuration?: number;
    /**
     * Gets or sets the whether the series viewer can allow the page to pan if a control pan is not possible in the requested direction.
    */
    isPagePanningAllowed?: boolean;
    /**
     * Determines the method of hit testing used when mousing over elements in the chart.
    */
    contentHitTestMode?: ChartHitTestMode;
    /**
     * Resolved method of hit testing used when the pointer is over elements in the chart.
    */
    actualContentHitTestMode?: ChartHitTestMode;
    /**
     * Gets or sets whether all surface interactions with the plot area should be disabled.
    */
    isSurfaceInteractionDisabled?: boolean;
    /**
     * The response to user panning and zooming: whether to update the view immediately while the user action is happening, or to defer the update to after the user action is complete.  The user action will be an action such as a mouse drag which causes panning and/or zooming to occur.
    */
    windowResponse?: WindowResponse;
    /**
     * Sets or gets the minimum width that the window rect is allowed to reach before being clamped.
     * Decrease this value if you want to allow for further zooming into the viewer.
     * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
    */
    windowRectMinWidth?: number;
    /**
     * Sets or gets the Synchronization channel to use for the SeriesViewer.
    */
    syncChannel?: string;
    /**
     * The visibility of the OverviewPlusDetailPane.
    */
    overviewPlusDetailPaneVisibility?: Visibility;
    /**
     * Gets or sets the current SeriesViewer's crosshair visibility override.
    */
    crosshairVisibility?: Visibility;
    /**
     * Gets or sets the brush used as the background for the current SeriesViewer object's plot area.
    */
    plotAreaBackground?: string;
    /**
     * Gets or sets the DefaultInteraction property.
     * The default interaction state defines the SeriesViewer's response to mouse events.
    */
    defaultInteraction?: InteractionState;
    /**
     * Gets or sets the current SeriesViewer's DragModifier property.
    */
    dragModifier?: ModifierKeys;
    /**
     * Gets or sets the current SeriesViewer's PanModifier property.
    */
    panModifier?: ModifierKeys;
    /**
     * Gets or sets the preview rectangle.
     * The preview rectangle may be set to Rect.Empty, in which case the visible preview
     * strokePath is hidden.
    */
    previewRect?: IgRect;
    /**
     * A number between 0 and 1 determining the position of the horizontal scroll.
     * This property is effectively a shortcut to the X position of the WindowRect property.
    */
    windowPositionHorizontal?: number;
    /**
     * A number between 0 and 1 determining the position of the vertical scroll.
     * This property is effectively a shortcut to the Y position of the WindowRect property.
    */
    windowPositionVertical?: number;
    /**
     * Text to display above the plot area.
    */
    chartTitle?: string;
    /**
     * Gets or sets the TitleHorizontalAlignment property.
    */
    titleHorizontalAlignment?: HorizontalAlignment;
    /**
     * Gets or sets the SubtitleHorizontalAlignment property.
    */
    subtitleHorizontalAlignment?: HorizontalAlignment;
    titleTextStyle?: string;
    subtitleTextStyle?: string;
    /**
     * Gets or sets the Color used for the Title Text.
    */
    titleTextColor?: string;
    /**
     * Gets or sets the Color used for the Subtitle Text.
    */
    subtitleTextColor?: string;
    /**
     * Margin applied above the title.
    */
    titleTopMargin?: number;
    /**
     * Margin applied to the left of the title.
    */
    titleLeftMargin?: number;
    /**
     * Margin applied to the right of the title.
    */
    titleRightMargin?: number;
    /**
     * Margin applied below the title.
    */
    titleBottomMargin?: number;
    /**
     * Margin applied above the subtitle.
    */
    subtitleTopMargin?: number;
    /**
     * Margin applied to the left of the subtitle.
    */
    subtitleLeftMargin?: number;
    /**
     * Margin applied to the right of the subtitle.
    */
    subtitleRightMargin?: number;
    /**
     * Margin applied below the subtitle.
    */
    subtitleBottomMargin?: number;
    /**
     * Gets or sets the Subtitle property.
     * The Title property defines the Subtitle of the chart
    */
    subtitle?: string;
    /**
     * Gets or sets the channel with which to synchronize.
    */
    SyncChannel?: string;
    /**
     * Gets or sets the bool used to display the window preview shadow.
    */
    SynchronizeVertically?: boolean;
    /**
     * Gets or sets the bool used to display the window preview shadow.
    */
    SynchronizeHorizontally?: boolean;
    /**
     * Sets or gets the top margin to use around the chart content.
    */
    topMargin?: number;
    /**
     * Sets or gets the left margin to use around the chart content.
    */
    leftMargin?: number;
    /**
     * Sets or gets the right margin to use around the chart content.
    */
    rightMargin?: number;
    /**
     * Sets or gets the bottom margin to use around the chart content.
    */
    bottomMargin?: number;
    /**
     * Sets or gets the automatic width to add when automatically adding margins to the chart.
    */
    autoMarginWidth?: number;
    /**
     * Sets or gets the automatic height to add when automatically adding margins to the chart.
    */
    autoMarginHeight?: number;
    /**
     * Gets or sets the IsAntiAliasingEnabledDuringInteraction property.
    */
    isAntiAliasingEnabledDuringInteraction?: boolean;
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    pixelScalingRatio?: number;
    /**
     * Method of pixel scaling to use during end user interaction with the chart.
    */
    interactionPixelScalingRatio?: number;
    /**
     * Uri for the background image to display behind the overview plus detail pane.
    */
    overviewPlusDetailPaneBackgroundImageUri?: string;
    /**
     * Gets the resolved pixel scaling ratio.
    */
    actualPixelScalingRatio?: number;
    /**
     * Resolved method of pixel scaling to use during end user interaction with the chart.
    */
    actualInteractionPixelScalingRatio?: number;
    /**
     * Gets the actual value of the window rectangle, which represents the current zoom level.
    */
    actualWindowRect?: IgRect;
    /**
     * A number between 0 and 1 determining the position of the horizontal scroll.
     * This property is effectively a shortcut to the Left of the ActualWindowRect property.
    */
    actualWindowPositionHorizontal?: number;
    /**
     * A number between 0 and 1 determining the position of the vertical scroll.
     * This property is effectively a shortcut to the Top of the ActualWindowRect property.
    */
    actualWindowPositionVertical?: number;
}
